@@ -1,8 +1,9 @@
 import threading
 from datetime import datetime, timezone
-from tinybird_cdk import config, tinybird
 
-LOCK = threading.Lock()
+from tinybird_cdk import config
+
+_LOCK = threading.Lock()
 
 def debug(message):
     log('DEBUG', message)
@@ -19,5 +20,5 @@ def error(message):
 def log(level, message):
     now = datetime.now(timezone.utc).astimezone().isoformat(timespec='seconds')
     tag = config.get('TB_CDK_TAG')
-    with LOCK:
+    with _LOCK:
         print(f'[{now}][{tag}][{level}] {message}')
