@@ -5,6 +5,7 @@ import httpx
 import humanize
 
 from . import config, errors, formats, logger
+from typing import Optional
 
 
 class Client:
@@ -29,10 +30,10 @@ class Client:
     # See https://www.python-httpx.org/advanced/#timeout-configuration.
     TIMEOUT = httpx.Timeout(5.0, read=None)
 
-    def __init__(self):
-        self.tb_cdk_token = config.get('TB_CDK_TOKEN')
-        self.tb_cdk_tag = config.get('TB_CDK_TAG')
-        self.tb_cdk_endpoint = config.get('TB_CDK_ENDPOINT', default='https://api.tinybird.co').rstrip('/')
+    def __init__(self, token: Optional[str]=None, cdk_tag: Optional[str]=None, tb_endpoint: Optional[str]=None):
+        self.tb_cdk_token = token or config.get('TB_CDK_TOKEN')
+        self.tb_cdk_tag = cdk_tag or config.get('TB_CDK_TAG')
+        self.tb_cdk_endpoint = tb_endpoint or config.get('TB_CDK_ENDPOINT', default='https://api.tinybird.co').rstrip('/')
         headers = {
             'Accept-Encoding': 'gzip',
             'Authorization': f"Bearer {self.tb_cdk_token}",
@@ -89,13 +90,14 @@ class Client:
     def replace_url(self, url, data_source, fmt, replace_condition=None):
         params = {'mode': 'replace', 'name': data_source, 'format': fmt, 'url': url, **self._fmt_params(fmt)}
         msg = [f'Replacing {data_source} with {url}', f'format = {fmt}']
+        data={}
 
         if replace_condition:
-            params['replace_condition'] = replace_condition
+            data['replace_condition'] = replace_condition
             msg.append(f'replace condition = "{replace_condition}"')
 
         logger.info(', '.join(msg))
-        job = self._post(self.DS_PATH, params=params).json()
+        job = self._post(self.DS_PATH, params=params, data=data).json()
         return self.wait_for_job(job)
 
     # --- Truncate --------------------------------------------------------------------------------
